@@ -13,6 +13,6 @@ def get(param, limit=None):
         try:
             tree = ElementTree.fromstring(r.content)
             file_urls = [post.attrib['file_url'] for post in tree.findall('post')]
-            return file_urls[:limit] if file_urls else None
+            return '\n'.join(file_urls[:limit]) if file_urls else None
         except Exception as e:
             raise Exception(f"ERROR: > {e}\n\n\nPlease Contact evergaster or Open a Issue in https://github.com/EverGasterXd/sara_api/issues")
\ No newline at end of file
